summaryrefslogtreecommitdiffstats
path: root/settings.py
diff options
context:
space:
mode:
authoreliott <eliott@cactuswax.net>2007-12-22 16:21:21 -0500
committereliott <eliott@cactuswax.net>2007-12-22 16:21:21 -0500
commitbd9a99d79193673caa568ab8c17edfd873e8a27e (patch)
treede6d7e346e98840662e2bd6f0fad70f4ed99b564 /settings.py
parentf02fdceef9a041f363732490769f1babc8f64515 (diff)
downloadarchweb-bd9a99d79193673caa568ab8c17edfd873e8a27e.tar.gz
archweb-bd9a99d79193673caa568ab8c17edfd873e8a27e.zip
renamed imports
Diffstat (limited to 'settings.py')
-rw-r--r--settings.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/settings.py b/settings.py
index 3de4a89d..f209f940 100644
--- a/settings.py
+++ b/settings.py
@@ -1,4 +1,4 @@
# Django settings for archlinux project.
## Import local settings
from local_settings import *
@@ -60,7 +60,7 @@ MIDDLEWARE_CLASSES += (
"django.middleware.doc.XViewMiddleware",
)
-ROOT_URLCONF = 'archlinux.urls'
+ROOT_URLCONF = 'archweb_dev.urls'
TEMPLATE_DIRS = (
# Put strings here, like "/home/html/django_templates".
@@ -78,12 +78,12 @@ INSTALLED_APPS = (
'django.contrib.sessions',
'django.contrib.sites',
'django.contrib.admin',
- 'archlinux.common',
- 'archlinux.news',
- 'archlinux.packages',
- 'archlinux.public',
- 'archlinux.todolists',
- 'archlinux.devel',
- 'archlinux.wiki'
+ 'archweb_dev.common',
+ 'archweb_dev.news',
+ 'archweb_dev.packages',
+ 'archweb_dev.public',
+ 'archweb_dev.todolists',
+ 'archweb_dev.devel',
+ 'archweb_dev.wiki'
)
@@ -1,4 +1,4 @@
-# Django settings for archlinux project.
+# Django settings for archweb_dev project.
## Import local settings
from local_settings import *